@@ -34,7 +34,9 @@ public:
     int maxResults;   ///< Maximum number of results to return
     QVariantHash customOptions;   ///< Custom search options
     bool resultFoundEnabled;   ///< Whether to enable result found notifications
+    bool detailedResultsEnabled;   ///< Whether to include detailed information in search results
     int syncSearchTimeoutSecs { 60 };
+    int batchTimeMs { 1000 };   ///< Batch processing time interval in milliseconds
 };
 
 DFM_SEARCH_END_NS
