@@ -77,18 +77,41 @@ Lucene::QueryPtr QueryBuilder::buildPinyinQuery(const QStringList &pinyins, Sear
     BooleanQueryPtr pinyinQuery = newLucene<BooleanQuery>();
 
     for (const QString &pinyin : pinyins) {
-        QString cleanPinyin = pinyin.trimmed().toLower();
+        QString cleanPinyin = pinyin.trimmed();
         if (!cleanPinyin.isEmpty() && Global::isPinyinSequence(cleanPinyin)) {
-            QueryPtr termQuery = newLucene<WildcardQuery>(
-                    newLucene<Term>(L"pinyin",
-                                    StringUtils::toUnicode(QString("*%1*").arg(cleanPinyin).toStdString())));
-            pinyinQuery->add(termQuery, op == SearchQuery::BooleanOperator::AND ? BooleanClause::MUST : BooleanClause::SHOULD);
+            // 复用buildCommonQuery，指定pinyin字段，让分析器自动处理匹配
+            QueryPtr termQuery = buildCommonQuery(cleanPinyin, false, newLucene<ChineseAnalyzer>(), "pinyin", false);
+            if (termQuery) {
+                pinyinQuery->add(termQuery, op == SearchQuery::BooleanOperator::AND ? BooleanClause::MUST : BooleanClause::SHOULD);
+            }
         }
     }
 
     return pinyinQuery;
 }
 
+Lucene::QueryPtr QueryBuilder::buildPinyinAcronymQuery(const QStringList &acronyms, SearchQuery::BooleanOperator op) const
+{
+    if (acronyms.isEmpty()) {
+        return nullptr;
+    }
+
+    BooleanQueryPtr acronymQuery = newLucene<BooleanQuery>();
+
+    for (const QString &acronym : acronyms) {
+        QString cleanAcronym = acronym.trimmed();
+        if (!cleanAcronym.isEmpty()) {
+            // 复用buildCommonQuery，指定pinyin_acronym字段，让分析器自动处理匹配
+            QueryPtr termQuery = buildCommonQuery(cleanAcronym, false, newLucene<ChineseAnalyzer>(), "pinyin_acronym", false);
+            if (termQuery) {
+                acronymQuery->add(termQuery, op == SearchQuery::BooleanOperator::AND ? BooleanClause::MUST : BooleanClause::SHOULD);
+            }
+        }
+    }
+
+    return acronymQuery;
+}
+
 Lucene::QueryPtr QueryBuilder::buildCommonQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer, bool allowWildcard) const
 {
     if (keyword.isEmpty() || !analyzer) {
@@ -107,6 +130,24 @@ Lucene::QueryPtr QueryBuilder::buildCommonQuery(const QString &keyword, bool cas
     return parser->parse(LuceneQueryUtils::processQueryString(keyword, caseSensitive));
 }
 
+Lucene::QueryPtr QueryBuilder::buildCommonQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer, const QString &fieldName, bool allowWildcard) const
+{
+    if (keyword.isEmpty() || !analyzer || fieldName.isEmpty()) {
+        return nullptr;
+    }
+
+    Lucene::QueryParserPtr parser = newLucene<Lucene::QueryParser>(
+            Lucene::LuceneVersion::LUCENE_CURRENT,
+            StringUtils::toUnicode(fieldName.toStdString()),
+            analyzer);
+
+    if (allowWildcard) {
+        parser->setAllowLeadingWildcard(true);
+    }
+
+    return parser->parse(LuceneQueryUtils::processQueryString(keyword, caseSensitive));
+}
+
 Lucene::QueryPtr QueryBuilder::buildSimpleQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer) const
 {
     return buildCommonQuery(keyword, caseSensitive, analyzer, false);
@@ -117,14 +158,14 @@ Lucene::QueryPtr QueryBuilder::buildWildcardQuery(const QString &keyword, bool c
     if (keyword.isEmpty()) {
         return nullptr;
     }
-    
+
     // 对于通配符查询，使用file_name_lower字段（非分词）而非file_name（分词）
     QString processedKeyword = caseSensitive ? keyword : keyword.toLower();
-    
+
     // 直接构建WildcardQuery，不使用QueryParser避免分词干扰
     return newLucene<WildcardQuery>(
-        newLucene<Term>(L"file_name_lower", 
-                       StringUtils::toUnicode(processedKeyword.toStdString())));
+            newLucene<Term>(L"file_name_lower",
+                            StringUtils::toUnicode(processedKeyword.toStdString())));
 }
 
 Lucene::QueryPtr QueryBuilder::buildBooleanQuery(const QStringList &terms, bool caseSensitive, SearchQuery::BooleanOperator op, const Lucene::AnalyzerPtr &analyzer) const
@@ -272,12 +313,13 @@ void FileNameIndexedStrategy::performIndexSearch(const SearchQuery &query, const
     QStringList fileTypes = api.fileTypes();
     QStringList fileExtensions = api.fileExtensions();
     bool pinyinEnabled = api.pinyinEnabled();
+    bool pinyinAcronymEnabled = api.pinyinAcronymEnabled();
 
     // 1. 确定搜索类型
-    SearchType searchType = determineSearchType(query, pinyinEnabled, fileTypes, fileExtensions);
+    SearchType searchType = determineSearchType(query, pinyinEnabled, pinyinAcronymEnabled, fileTypes, fileExtensions);
 
     // 2. 构建查询
-    IndexQuery indexQuery = buildIndexQuery(query, searchType, caseSensitive, pinyinEnabled, fileTypes, fileExtensions);
+    IndexQuery indexQuery = buildIndexQuery(query, searchType, caseSensitive, pinyinEnabled, pinyinAcronymEnabled, fileTypes, fileExtensions);
 
     // 3. 执行查询并处理结果
     executeIndexQuery(indexQuery, searchPath, searchExcludedPaths);
@@ -286,6 +328,7 @@ void FileNameIndexedStrategy::performIndexSearch(const SearchQuery &query, const
 FileNameIndexedStrategy::SearchType FileNameIndexedStrategy::determineSearchType(
         const SearchQuery &query,
         bool pinyinEnabled,
+        bool pinyinAcronymEnabled,
         const QStringList &fileTypes,
         const QStringList &fileExtensions) const
 {
@@ -321,9 +364,28 @@ FileNameIndexedStrategy::SearchType FileNameIndexedStrategy::determineSearchType
         return SearchType::Boolean;
     }
 
-    // 启用拼音搜索
-    if (pinyinEnabled && !isBoolean) {
-        return SearchType::Pinyin;
+    if ((pinyinEnabled || pinyinAcronymEnabled) && !isBoolean) {
+        // 如果同时启用了拼音和拼音首字母
+        if (pinyinEnabled && pinyinAcronymEnabled) {
+            // 检查关键词是否为有效拼音序列
+            if (hasKeyword && Global::isPinyinSequence(keyword)) {
+                return SearchType::Pinyin;
+            } else if (hasKeyword && Global::isPinyinAcronymSequence(keyword)) {
+                // 不是有效拼音序列，但是有效的拼音首字母，fallback到拼音首字母搜索
+                return SearchType::PinyinAcronym;
+            } else {
+                // 既不是拼音也不是有效的拼音首字母，使用简单搜索
+                return SearchType::Simple;
+            }
+        }
+        // 只启用拼音搜索
+        else if (pinyinEnabled) {
+            return SearchType::Pinyin;
+        }
+        // 只启用拼音首字母搜索
+        else if (pinyinAcronymEnabled) {
+            return SearchType::PinyinAcronym;
+        }
     }
 
     // 默认简单搜索
@@ -335,6 +397,7 @@ FileNameIndexedStrategy::IndexQuery FileNameIndexedStrategy::buildIndexQuery(
         SearchType searchType,
         bool caseSensitive,
         bool pinyinEnabled,
+        bool pinyinAcronymEnabled,
         const QStringList &fileTypes,
         const QStringList &fileExtensions)
 {
@@ -344,6 +407,7 @@ FileNameIndexedStrategy::IndexQuery FileNameIndexedStrategy::buildIndexQuery(
     result.fileTypes = fileTypes;
     result.fileExtensions = fileExtensions;
     result.usePinyin = pinyinEnabled;   // 设置拼音搜索标志
+    result.usePinyinAcronym = pinyinAcronymEnabled;   // 设置拼音首字母搜索标志
 
     switch (searchType) {
     case SearchType::Simple:
@@ -359,6 +423,9 @@ FileNameIndexedStrategy::IndexQuery FileNameIndexedStrategy::buildIndexQuery(
     case SearchType::Pinyin:
         result.terms.append(query.keyword());
         break;
+    case SearchType::PinyinAcronym:
+        result.terms.append(query.keyword());
+        break;
     case SearchType::FileType:
         result.fileTypes = fileTypes;
         break;
@@ -566,6 +633,31 @@ Lucene::QueryPtr FileNameIndexedStrategy::buildLuceneQuery(const IndexQuery &que
             }
         }
         break;
+    case SearchType::PinyinAcronym:
+        if (!query.terms.isEmpty()) {
+            BooleanQueryPtr combinedQuery = newLucene<BooleanQuery>();
+
+            // 添加拼音首字母查询
+            if (Global::isPinyinAcronymSequence(query.terms.first())) {
+                QueryPtr pinyinAcronymQuery = m_queryBuilder->buildPinyinAcronymQuery(query.terms);
+                if (pinyinAcronymQuery) {
+                    combinedQuery->add(pinyinAcronymQuery, BooleanClause::SHOULD);
+                    hasValidQuery = true;
+                }
+            }
+
+            // 添加普通关键词查询
+            QueryPtr simpleQuery = m_queryBuilder->buildSimpleQuery(query.terms.first(), query.caseSensitive, analyzer);
+            if (simpleQuery) {
+                combinedQuery->add(simpleQuery, BooleanClause::SHOULD);
+                hasValidQuery = true;
+            }
+
+            if (hasValidQuery) {
+                finalQuery->add(combinedQuery, BooleanClause::MUST);
+            }
+        }
+        break;
     case SearchType::FileType:
         if (!query.fileTypes.isEmpty()) {
             QueryPtr typeQuery = m_queryBuilder->buildTypeQuery(query.fileTypes);
@@ -652,6 +744,15 @@ BooleanQueryPtr FileNameIndexedStrategy::buildBooleanTermsQuery(const IndexQuery
             }
         }
 
+        // 添加拼音首字母查询
+        if (query.usePinyinAcronym && Global::isPinyinAcronymSequence(term)) {
+            QueryPtr pinyinAcronymQuery = m_queryBuilder->buildPinyinAcronymQuery(QStringList { term });
+            if (pinyinAcronymQuery) {
+                termQuery->add(pinyinAcronymQuery, BooleanClause::SHOULD);
+                termHasQuery = true;
+            }
+        }
+
         // 将当前词的查询添加到最终查询中，维持原始bool逻辑
         if (termHasQuery) {
             booleanQuery->add(termQuery, query.booleanOp == SearchQuery::BooleanOperator::AND ? BooleanClause::MUST : BooleanClause::SHOULD);
